#!/bin/bash

## for using postinstall script by wildix-base package
RAM="$(free -m | grep '^Mem:' | awk {'print $2'})"

[ -z $RAM ] && log "ERROR: zero values (exit)" "${0##*/}" && exit 0


__SET_FPM() {

crudini --set ${www_conf} www pm.max_children $1
crudini --set ${www_conf} www pm.start_servers $2
crudini --set ${www_conf} www pm.min_spare_servers $3
crudini --set ${www_conf} www pm.max_spare_servers $4
crudini --set ${www_conf} www pm.max_requests $5
crudini --set ${www_conf} www pm.process_idle_timeout 30s

}

php_ver=$(php -v | head -n 1 | cut -d " " -f 2 | cut -f1-2 -d".")

www_conf="/etc/php/$php_ver/fpm/pool.d/www.conf"
fpm_conf="/etc/php/$php_ver/fpm/php-fpm.conf"
fpm_phpini="/etc/php/$php_ver/fpm/php.ini"
cli_phpini="/etc/php/$php_ver/cli/php.ini"
php_override="/etc/systemd/system/php${php_ver}-fpm.service.d/override.conf"



# set dynamic PM values
if [ "$RAM" -le "1024" ]; then
    __SET_FPM 3 1 1 1 500
elif [ "$RAM" -gt "1024" ] && [ "$RAM" -le "2048" ]; then
    __SET_FPM 5 1 1 2 500
elif [ "$RAM" -gt "2048" ] && [ "$RAM" -le "4096" ]; then
    __SET_FPM 10 2 2 3 500
elif [ "$RAM" -gt "4096" ] && [ "$RAM" -le "8192" ]; then
    __SET_FPM 50 2 2 20 500
elif [ "$RAM" -gt "8192" ]; then
    __SET_FPM 100 5 5 40 500
fi

## php-fpm.conf changes
crudini --del ${fpm_conf} global include
crudini --set ${fpm_conf} global error_log syslog
crudini --set ${fpm_conf} global pid /run/php/php-fpm.pid
crudini --set ${fpm_conf} global log_level notice
crudini --set ${fpm_conf} global syslog.ident php-fpm
crudini --set ${fpm_conf} global syslog.facility daemon
crudini --set ${fpm_conf} global include "/etc/php/$php_ver/fpm/pool.d/*.conf"

## www.conf changes
crudini --set ${www_conf} www catch_workers_output yes


# override to launch php processed under wms user
crudini --set ${www_conf} www listen.owner wms
crudini --set ${www_conf} www listen.group wms
crudini --set ${www_conf} www listen /run/php/php-fpm.sock
crudini --set ${www_conf} www user wms
crudini --set ${www_conf} www group wms

## fpm php.ini changes
crudini --set ${fpm_phpini} mbstring mbstring.detect_order auto
crudini --set ${fpm_phpini} Session session.save_path /tmp/session/lighty/
crudini --set ${fpm_phpini} Session session.gc_maxlifetime 129600
crudini --set ${fpm_phpini} Session session.cookie_httponly 1
crudini --set ${fpm_phpini} Session session.cookie_lifetime 604800
crudini --set ${fpm_phpini} 'mail function' mail.add_x_header On
crudini --set ${fpm_phpini} PHP upload_max_filesize 128M
crudini --set ${fpm_phpini} PHP upload_tmp_dir /tmp/session/
crudini --set ${fpm_phpini} PHP post_max_size 128M
crudini --set ${fpm_phpini} PHP error_log syslog
crudini --set ${fpm_phpini} PHP track_errors Off
crudini --set ${fpm_phpini} PHP error_reporting "E_ALL & ~E_NOTICE & ~E_STRICT"
crudini --set ${fpm_phpini} PHP memory_limit 32M
crudini --set ${fpm_phpini} PHP max_execution_time 60
crudini --set ${fpm_phpini} PHP serialize_precision 17
crudini --set ${fpm_phpini} PHP output_buffering Off
crudini --set ${fpm_phpini} PHP short_open_tag On
crudini --set ${fpm_phpini} PHP engine Off

## cli php.ini changes
crudini --set ${cli_phpini} "mail function" mail.add_x_header On
crudini --set ${cli_phpini} PHP upload_max_filesize 10M
crudini --set ${cli_phpini} PHP post_max_size 10M
crudini --set ${cli_phpini} PHP register_argc_argv On
crudini --set ${cli_phpini} PHP error_log syslog
crudini --set ${cli_phpini} PHP track_errors Off
crudini --set ${cli_phpini} PHP error_reporting "E_ALL & ~E_NOTICE & ~E_STRICT"
crudini --set ${cli_phpini} PHP memory_limit -1
crudini --set ${cli_phpini} PHP max_execution_time 60
crudini --set ${cli_phpini} PHP serialize_precision 17
crudini --set ${cli_phpini} PHP output_buffering Off
crudini --set ${cli_phpini} PHP short_open_tag On
crudini --set ${cli_phpini} PHP engine Off

[ ! -f $php_override ] && mkdir -p /etc/systemd/system/php${php_ver}-fpm.service.d && touch $php_override
crudini --set ${php_override} Service KillMode process
systemctl daemon-reload
